unit Unit1;

interface

uses
  Windows, Classes, Forms, SysUtils, Buttons, ExtCtrls, SageUnit, Controls,
  StdCtrls;

type
  TForm1 = class(TForm)
    ListBox1: TListBox;
    GroupBox1: TGroupBox;
    BtnStatus: TButton;
    Edit1: TEdit;
    Label1: TLabel;
    Bevel1: TBevel;
    btnEnable: TBitBtn;
    btnDisable: TBitBtn;
    Label2: TLabel;
    GroupBox2: TGroupBox;
    btnAddTask: TBitBtn;
    btnChangeTask: TBitBtn;
    btnRemoveTask: TBitBtn;
    btnGetTask: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure BtnStatusClick(Sender: TObject);
    procedure btnEnableClick(Sender: TObject);
    procedure btnDisableClick(Sender: TObject);
    procedure btnGetTaskClick(Sender: TObject);
    procedure btnChangeTaskClick(Sender: TObject);
    procedure btnAddTaskClick(Sender: TObject);
    procedure btnRemoveTaskClick(Sender: TObject);
  private
    { Private declarations }
    Sage: TSage;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

Uses Unit2, SageData;
{$R *.DFM}

{------------------------------------------------------------------------------}
procedure TForm1.FormCreate(Sender: TObject);
begin
     Sage := TSage.Create( Application );
     If Sage.Detected > 0 then begin
        Sage.Initialize;
        BtnStatusClick( Self );
     end else
         GenError( ERROR_AGENT_NOT_PRESENT );

end;

{------------------------------------------------------------------------------}
procedure TForm1.btnEnableClick(Sender: TObject);
begin
     Sage.Enable;
end;

{------------------------------------------------------------------------------}
procedure TForm1.btnDisableClick(Sender: TObject);
begin
     Sage.Disable;
end;

{------------------------------------------------------------------------------}
procedure TForm1.BtnStatusClick(Sender: TObject);
begin
     Edit1.Text := IntToStr( Sage.GetStatus );
end;

{------------------------------------------------------------------------------}
procedure TForm1.btnGetTaskClick(Sender: TObject);
var
   nLoop : integer;
   rc    : integer;
begin
     rc := Sage.GetTaskList;
     if rc < 0 then
        GenError( rc )
     else begin
          ListBox1.Items.Clear;
          for nLoop := 0 to ( Sage.NumTask-1 ) do
              ListBox1.Items.Add( Sage.pTaskList[nLoop].Comment );
     end;
end;

{------------------------------------------------------------------------------}
procedure TForm1.btnChangeTaskClick(Sender: TObject);
var
   Task     : TaskInfo;
   TaskId   : cardinal;
   TaskPos  : integer;
   rc       : integer;
begin

     If ListBox1.ItemIndex = -1 then
        exit;

     TaskId := Sage.pTaskList[ ListBox1.ItemIndex ].Task_Identifier;
     rc := Sage.LockTask( TaskId, FALSE );
     If  rc <> 0 then begin
        GenError( rc );
        exit;
     end;

     {The task must be in the same position, but one never knows....}
     TaskPos := Sage.SearchTask( TaskID );
     If TaskPos = -1 then begin
        GenError( ERROR_TASK_NOT_PRESENT );
        rc := Sage.UnlockTask( TaskId, FALSE );
        If rc <> 0 then
           GenError( rc );
        exit;
     end;

     Task   := Sage.pTaskList[ TaskPos ];
     TaskId := Task.Task_Identifier;
     Form2.EntryForm( Task );

     If Form2.ModalResult = mrOk then begin
          rc := Sage.ChangeTask( Task, TaskId );
          If rc <> 0 then
             GenError( rc );
     end;

     rc := Sage.UnlockTask( TaskId, FALSE );
     If rc <> 0 then
        GenError( rc );

     {Refresh TaskList}
     btnGetTaskClick( Self );
     ListBox1.ItemIndex := TaskPos;
     ListBox1.SetFocus;

end;

{------------------------------------------------------------------------------}
procedure TForm1.btnAddTaskClick(Sender: TObject);
Var
   Task   : TaskInfo;
   BeginT : TSystemTime;
   TaskId : cardinal;
   rc     : integer;
begin
     EmptyTask( Task );

     GetLocalTime( BeginT );
     with BeginT do begin
          wMinute := wMinute + 1;
          wSecond := 0;
     end;

     With Task do begin
          Begintime           := BeginT;
          AlarmEnabled        := #1;
          CommandLine         := 'c:\windows\notepad.exe';
          Comment             := 'SAGE add Task Demostration';
     end;

     rc := Sage.AddTask( Task, TaskId );
     If  rc <> 0 then
        GenError( rc )
     else begin
          {Refresh TaskList}
          btnGetTaskClick( Self );
          ListBox1.ItemIndex := ListBox1.Items.Count;
          ListBox1.SetFocus;
     end;

end;

{------------------------------------------------------------------------------}
procedure TForm1.btnRemoveTaskClick(Sender: TObject);
var
   TaskId : Cardinal;
   rc     : integer;
begin
     If ListBox1.ItemIndex = -1 then
        exit;

     TaskId := Sage.pTaskList[ ListBox1.ItemIndex ].Task_Identifier;
     rc := Sage.RemoveTask( TaskId );
     If rc <> 0 then
        GenError( rc )
     else begin
          {Refresh TaskList}
          btnGetTaskClick( Self );
          ListBox1.ItemIndex := ListBox1.Items.Count;
          ListBox1.SetFocus;
     end;

end;

end.
